<?php
App::uses('HttpSocket', 'Network/Http');
App::uses('DataSource', 'Model/Datasource');

class BuzzSource extends DataSource {

	protected $_schema = [];

	public function __construct($config) {
		parent::__construct($config);
		$this->Http = new HttpSocket();
	}

	public function describe($model) {
		return $this->_schema;
	}

	public function read(Model $model, $queryData = array(), $recursive = null) {
		$json = $this->Http->get(
			$this->config['host'] . '/' . $queryData['method'],
			$queryData['conditions']
		);

		$response = json_decode($json, true);

		// Log the API call.
		$this->_logApiCall($this->config['host'] . '/' . $queryData['method'], $queryData['conditions'], $json);

		if (is_null($response)) {
			$error = json_last_error();
			throw new CakeException($error);
		}

		return [$model->alias => $response];
	}

/**
 * Logs API calls
 *
 * @param string $url
 * @param array $params
 * @param string $data
 * @return void
 */
	protected function _logApiCall($url, array $params, $data) {
		$this->log($url, 'api');
		$this->log($params, 'api');
		$this->log($data, 'api');
		return;
	}

}
